import { DefaultAttribute, HelperElement, ModifyXmlCallback, OverrideAttribute, RelationshipAttribute, XmlDocument, XmlElement } from '../types/xml-types';
import { GetRelationshipsCallback, Target } from '../types/types';
import IArchive from '../interfaces/iarchive';
export declare class XmlHelper {
    static modifyXmlInArchive(archive: IArchive, file: string, callbacks: ModifyXmlCallback[]): Promise<void>;
    static getXmlFromArchive(archive: IArchive, file: string): Promise<XmlDocument>;
    static writeXmlToArchive(archive: IArchive, file: string, xml: XmlDocument): void;
    static appendIf(element: HelperElement): Promise<HelperElement | boolean>;
    static append(element: HelperElement): Promise<HelperElement>;
    static removeIf(element: HelperElement): Promise<XmlElement[]>;
    static getNextRelId(rootArchive: IArchive, file: string): Promise<string>;
    static getMaxId(rels: NodeListOf<ChildNode> | HTMLCollectionOf<XmlElement>, attribute: string, increment?: boolean, minId?: number): number;
    static getTargetsFromRelationships(archive: IArchive, path: string, prefix: string | string[]): Promise<Target[]>;
    static pushRelTargets(element: XmlElement, prefix: string, targets: Target[]): void;
    static targetMatchesRelationship(relType: any, subtype: any, target: any, prefix: any): boolean;
    static getTargetsByRelationshipType(archive: IArchive, path: string, type: string): Promise<Target[]>;
    static getRelationships(archive: IArchive, path: string, cb: GetRelationshipsCallback): Promise<Target[]>;
    static getRelationshipItems(archive: IArchive, path: string, tag: string, cb: GetRelationshipsCallback): Promise<Target[]>;
    static findByAttribute(xml: XmlDocument | Document, tagName: string, attributeName: string, attributeValue: string): boolean;
    static replaceAttribute(archive: IArchive, path: string, tagName: string, attributeName: string, attributeValue: string, replaceValue: string): Promise<void>;
    static getTargetByRelId(archive: IArchive, slideNumber: number, element: XmlDocument, type: string): Promise<Target>;
    static findByElementCreationId(archive: IArchive, path: string, creationId: string): Promise<XmlDocument>;
    static findByElementName(archive: IArchive, path: string, name: string): Promise<XmlDocument>;
    static findByName(doc: Document, name: string): XmlDocument;
    static findByCreationId(doc: Document, creationId: string): XmlDocument;
    static findFirstByAttributeValue(nodes: NodeListOf<ChildNode> | HTMLCollectionOf<XmlElement>, attributeName: string, attributeValue: string): XmlElement;
    static findByAttributeValue(nodes: NodeListOf<ChildNode> | HTMLCollectionOf<XmlElement>, attributeName: string, attributeValue: string): XmlElement[];
    static createContentTypeChild(archive: IArchive, attributes: OverrideAttribute | DefaultAttribute): HelperElement;
    static createRelationshipChild(archive: IArchive, targetRelFile: string, attributes: RelationshipAttribute): HelperElement;
    static appendSharedString(sharedStrings: Document, stringValue: string): number;
    static insertAfter(newNode: Node, referenceNode: XmlElement): Node;
    static sliceCollection(collection: HTMLCollectionOf<XmlElement>, length: number, from?: number): void;
    static remove(toRemove: XmlElement): void;
    static sortCollection(collection: HTMLCollectionOf<XmlElement>, order: number[], callback?: ModifyXmlCallback): void;
    static modifyCollection(collection: HTMLCollectionOf<XmlElement>, callback: ModifyXmlCallback): void;
    static dump(element: XmlDocument | XmlElement): void;
}
